aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorAsh Ketchum <no-reply@sl0p.foo>2026-07-15 02:21:56 +0200
committerAsh Ketchum <no-reply@sl0p.foo>2026-07-15 02:21:56 +0200
commit68216af4bf4c859c6f3cbbc1303500e345d1c8db (patch)
tree4cae80697dd7e9b69206d53b3f389800468e80a9
parentmenu: add NOWILD toggle + REPEL (and repurpose wc5d8 as the flag) (diff)
downloadpokeyellow-68216af4bf4c859c6f3cbbc1303500e345d1c8db.tar.gz
pokeyellow-68216af4bf4c859c6f3cbbc1303500e345d1c8db.tar.xz
pokeyellow-68216af4bf4c859c6f3cbbc1303500e345d1c8db.zip
menu: COINS cheat + expand ITEMS with evolution stones (12 items)
COINS sets game-corner coins to 9999. ITEMS submenu grows to 12: balls, Rare Candy, Full Restore, Max Revive, Max Elixer, PP Up, and all five evolution stones (Moon/Fire/Thunder/Water/Leaf). Top menu is now 10 entries.
-rw-r--r--engine/slop_menu.asm27
1 files changed, 21 insertions, 6 deletions
diff --git a/engine/slop_menu.asm b/engine/slop_menu.asm
index 36773423..4ec7b1e8 100644
--- a/engine/slop_menu.asm
+++ b/engine/slop_menu.asm
@@ -8,7 +8,7 @@
; To add an entry: add a "NAME" line to SlopMenuText, a `dw Handler` to
; SlopMenuHandlers, and bump SLOP_MENU_COUNT.
-DEF SLOP_MENU_COUNT EQU 9
+DEF SLOP_MENU_COUNT EQU 10
SECTION "Slop Menu", ROMX
@@ -32,11 +32,11 @@ SlopMenu::
hlcoord 6, 3
ld de, SlopMenuText
call PlaceString
; ON marker for the NOWILD toggle (item 7 -> row 10)
ld a, [wSlopNoWild]
and a
jr z, .nowildOff
- hlcoord 13, 10
+ hlcoord 13, 11
ld de, SlopOnText
call PlaceString
.nowildOff
@@ -107,6 +107,7 @@ SlopMenuText:
db "WARP"
next "HEAL"
next "MONEY"
+ next "COINS"
next "BADGES"
next "DEX"
next "MAXTEAM"
@@ -119,6 +120,7 @@ SlopMenuHandlers:
dw WarpSubmenu
dw SlopHealParty
dw SlopMaxCash
+ dw SlopMaxCoins
dw SlopAllBadges
dw SlopDex
dw SlopMaxTeam
@@ -205,7 +207,7 @@ WarpMapTable:
; ===========================================================================
; ITEMS submenu: give 99 of the chosen item (stacks via GiveItem)
; ===========================================================================
-DEF GIVE_COUNT EQU 8
+DEF GIVE_COUNT EQU 12
GiveItemSubmenu:
call ClearScreen
@@ -256,10 +258,15 @@ GiveItemText:
next "MAX REVIVE"
next "MAX ELIXER"
next "PP UP"
- next "NUGGET@"
+ next "MOON STONE"
+ next "FIRE STONE"
+ next "THUNDERSTONE"
+ next "WATER STONE"
+ next "LEAF STONE@"
GiveItemTable:
db MASTER_BALL, ULTRA_BALL, RARE_CANDY, FULL_RESTORE
- db MAX_REVIVE, MAX_ELIXER, PP_UP, NUGGET
+ db MAX_REVIVE, MAX_ELIXER, PP_UP, MOON_STONE
+ db FIRE_STONE, THUNDER_STONE, WATER_STONE, LEAF_STONE
; ===========================================================================
@@ -312,6 +319,14 @@ SlopMaxCash:
and a
ret
+; COINS: 9999 game-corner coins (BCD)
+SlopMaxCoins:
+ ld a, $99
+ ld [wPlayerCoins], a
+ ld [wPlayerCoins + 1], a
+ and a
+ ret
+
; NOWILD toggle: no wild encounters (hooked in TryDoWildEncounter)
SlopToggleNoWild:
ld a, [wSlopNoWild]
@@ -32,11 +32,11 @@ SlopMenu::
ld de, SlopMenuText
call PlaceString
-; ON marker for the NOWILD toggle (item 7 -> row 10)
+; ON marker for the NOWILD toggle (item 8 -> row 11)
ld a, [wSlopNoWild]
and a